@@ -1,12 +1,19 @@
-"Main interface for sts service Client"
-from __future__ import annotations
+"""
+Main interface for sts service client
 
-from typing import Any, Dict, List
-from botocore.client import BaseClient
+Usage::
+
+    import boto3
+    from mypy_boto3.sts import STSClient
+
+    session = boto3.Session()
+
+    client: STSClient = boto3.client("sts")
+    session_client: STSClient = session.client("sts")
+"""
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
+from typing import Any, Dict, List, TYPE_CHECKING
 from botocore.exceptions import ClientError as Boto3ClientError
-
-# pylint: disable=import-self
-import mypy_boto3_sts.client as client_scope
 from mypy_boto3_sts.type_defs import (
     AssumeRoleResponseTypeDef,
     AssumeRoleWithSAMLResponseTypeDef,
@@ -24,14 +31,25 @@ from mypy_boto3_sts.type_defs import (
 __all__ = ("STSClient",)
 
 
-class STSClient(BaseClient):
+class Exceptions:
+    ClientError: Boto3ClientError
+    ExpiredTokenException: Boto3ClientError
+    IDPCommunicationErrorException: Boto3ClientError
+    IDPRejectedClaimException: Boto3ClientError
+    InvalidAuthorizationMessageException: Boto3ClientError
+    InvalidIdentityTokenException: Boto3ClientError
+    MalformedPolicyDocumentException: Boto3ClientError
+    PackedPolicyTooLargeException: Boto3ClientError
+    RegionDisabledException: Boto3ClientError
+
+
+class STSClient:
     """
-    [STS.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.43/reference/services/sts.html#STS.Client)
+    [STS.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/sts.html#STS.Client)
     """
 
-    exceptions: client_scope.Exceptions
+    exceptions: Exceptions
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def assume_role(
         self,
         RoleArn: str,
@@ -46,10 +64,9 @@ class STSClient(BaseClient):
         TokenCode: str = None,
     ) -> AssumeRoleResponseTypeDef:
         """
-        [Client.assume_role documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.43/reference/services/sts.html#STS.Client.assume_role)
+        [Client.assume_role documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/sts.html#STS.Client.assume_role)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def assume_role_with_saml(
         self,
         RoleArn: str,
@@ -60,10 +77,9 @@ class STSClient(BaseClient):
         DurationSeconds: int = None,
     ) -> AssumeRoleWithSAMLResponseTypeDef:
         """
-        [Client.assume_role_with_saml documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.43/reference/services/sts.html#STS.Client.assume_role_with_saml)
+        [Client.assume_role_with_saml documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/sts.html#STS.Client.assume_role_with_saml)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def assume_role_with_web_identity(
         self,
         RoleArn: str,
@@ -75,48 +91,42 @@ class STSClient(BaseClient):
         DurationSeconds: int = None,
     ) -> AssumeRoleWithWebIdentityResponseTypeDef:
         """
-        [Client.assume_role_with_web_identity documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.43/reference/services/sts.html#STS.Client.assume_role_with_web_identity)
+        [Client.assume_role_with_web_identity documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/sts.html#STS.Client.assume_role_with_web_identity)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.43/reference/services/sts.html#STS.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/sts.html#STS.Client.can_paginate)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def decode_authorization_message(
         self, EncodedMessage: str
     ) -> DecodeAuthorizationMessageResponseTypeDef:
         """
-        [Client.decode_authorization_message documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.43/reference/services/sts.html#STS.Client.decode_authorization_message)
+        [Client.decode_authorization_message documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/sts.html#STS.Client.decode_authorization_message)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def generate_presigned_url(
         self,
         ClientMethod: str,
         Params: Dict[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
-    ) -> None:
+    ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.43/reference/services/sts.html#STS.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/sts.html#STS.Client.generate_presigned_url)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def get_access_key_info(self, AccessKeyId: str) -> GetAccessKeyInfoResponseTypeDef:
         """
-        [Client.get_access_key_info documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.43/reference/services/sts.html#STS.Client.get_access_key_info)
+        [Client.get_access_key_info documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/sts.html#STS.Client.get_access_key_info)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def get_caller_identity(self) -> GetCallerIdentityResponseTypeDef:
         """
-        [Client.get_caller_identity documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.43/reference/services/sts.html#STS.Client.get_caller_identity)
+        [Client.get_caller_identity documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/sts.html#STS.Client.get_caller_identity)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def get_federation_token(
         self,
         Name: str,
@@ -126,25 +136,12 @@ class STSClient(BaseClient):
         Tags: List[TagTypeDef] = None,
     ) -> GetFederationTokenResponseTypeDef:
         """
-        [Client.get_federation_token documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.43/reference/services/sts.html#STS.Client.get_federation_token)
+        [Client.get_federation_token documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/sts.html#STS.Client.get_federation_token)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def get_session_token(
         self, DurationSeconds: int = None, SerialNumber: str = None, TokenCode: str = None
     ) -> GetSessionTokenResponseTypeDef:
         """
-        [Client.get_session_token documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.43/reference/services/sts.html#STS.Client.get_session_token)
+        [Client.get_session_token documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/sts.html#STS.Client.get_session_token)
         """
-
-
-class Exceptions:
-    ClientError: Boto3ClientError
-    ExpiredTokenException: Boto3ClientError
-    IDPCommunicationErrorException: Boto3ClientError
-    IDPRejectedClaimException: Boto3ClientError
-    InvalidAuthorizationMessageException: Boto3ClientError
-    InvalidIdentityTokenException: Boto3ClientError
-    MalformedPolicyDocumentException: Boto3ClientError
-    PackedPolicyTooLargeException: Boto3ClientError
-    RegionDisabledException: Boto3ClientError
